@@ -1101,7 +1101,7 @@ gedit_document_get_uri_for_display (GeditDocument *doc)
 
 	if (location == NULL)
 	{
-		return g_strdup_printf (_("Unsaved Document %d"),
+		return g_strdup_printf (_("Untitled Document %d"),
 					priv->untitled_number);
 	}
 	else
@@ -1134,7 +1134,7 @@ gedit_document_get_short_name_for_display (GeditDocument *doc)
 	}
 	else if (location == NULL)
 	{
-		return g_strdup_printf (_("Unsaved Document %d"),
+		return g_strdup_printf (_("Untitled Document %d"),
 					priv->untitled_number);
 	}
 	else
@@ -1474,8 +1474,6 @@ gboolean
 gedit_document_goto_line (GeditDocument *doc,
 			  gint           line)
 {
-	gboolean ret = TRUE;
-	guint line_count;
 	GtkTextIter iter;
 
 	gedit_debug (DEBUG_DOCUMENT);
@@ -1483,24 +1481,13 @@ gedit_document_goto_line (GeditDocument *doc,
 	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), FALSE);
 	g_return_val_if_fail (line >= -1, FALSE);
 
-	line_count = gtk_text_buffer_get_line_count (GTK_TEXT_BUFFER (doc));
-
-	if (line >= line_count)
-	{
-		ret = FALSE;
-		gtk_text_buffer_get_end_iter (GTK_TEXT_BUFFER (doc),
-					      &iter);
-	}
-	else
-	{
-		gtk_text_buffer_get_iter_at_line (GTK_TEXT_BUFFER (doc),
-						  &iter,
-						  line);
-	}
+	gtk_text_buffer_get_iter_at_line (GTK_TEXT_BUFFER (doc),
+					  &iter,
+					  line);
 
 	gtk_text_buffer_place_cursor (GTK_TEXT_BUFFER (doc), &iter);
 
-	return ret;
+	return gtk_text_iter_get_line (&iter) == line;
 }
 
 gboolean
@@ -1508,36 +1495,21 @@ gedit_document_goto_line_offset (GeditDocument *doc,
 				 gint           line,
 				 gint           line_offset)
 {
-	gboolean ret;
 	GtkTextIter iter;
 
 	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), FALSE);
 	g_return_val_if_fail (line >= -1, FALSE);
 	g_return_val_if_fail (line_offset >= -1, FALSE);
 
-	ret = gedit_document_goto_line (doc, line);
+	gtk_text_buffer_get_iter_at_line_offset (GTK_TEXT_BUFFER (doc),
+						 &iter,
+						 line,
+						 line_offset);
 
-	if (ret)
-	{
-		guint offset_count;
+	gtk_text_buffer_place_cursor (GTK_TEXT_BUFFER (doc), &iter);
 
-		gtk_text_buffer_get_iter_at_line (GTK_TEXT_BUFFER (doc),
-						  &iter,
-						  line);
-
-		offset_count = gtk_text_iter_get_chars_in_line (&iter);
-		if (line_offset > offset_count)
-		{
-			ret = FALSE;
-		}
-		else
-		{
-			gtk_text_iter_set_line_offset (&iter, line_offset);
-			gtk_text_buffer_place_cursor (GTK_TEXT_BUFFER (doc), &iter);
-		}
-	}
-
-	return ret;
+	return (gtk_text_iter_get_line (&iter) == line &&
+		gtk_text_iter_get_line_offset (&iter) == line_offset);
 }
 
 /**
